'use strict';

Object.defineProperty(exports, "__esModule", {
  value: true
});

var _babelTemplate = require('babel-template');

var _babelTemplate2 = _interopRequireDefault(_babelTemplate);

function _interopRequireDefault(obj) { return obj && obj.__esModule ? obj : { default: obj }; }

const DISPLAY_NAME = '@displayName'; //  weak


const buildDisplayName = (0, _babelTemplate2.default)(`
CLASS.PROP.displayName = VALUE;
`);

function shouldDisplayName(comments) {
  return comments && comments.find(comment => {
    return comment.value.trim() === DISPLAY_NAME;
  });
}

exports.default = ({ types: t }) => {
  return {
    name: 'babel-plugin-display-name',
    visitor: {
      ClassProperty(path) {
        if (path.node.static && shouldDisplayName(path.node.leadingComments)) {
          const classNode = path.findParent(parent => parent.isClassDeclaration());
          if (classNode) {
            const className = classNode.get('id').node.name;
            const prop = path.get('key').node.name;
            classNode.insertAfter(buildDisplayName({
              CLASS: t.identifier(className),
              PROP: t.identifier(prop),
              VALUE: t.stringLiteral(`${className}.${prop}`)
            }));
          }
        }
      }
    }
  };
};